@@ -21,7 +21,6 @@
  */
 #ifndef _DIR_H
 #define _DIR_H
-#include "list.h"
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -34,7 +33,7 @@ struct dir_data
   void *display;
   char current_directory[DIR_NAME_LEN];
   unsigned long int current_inode;
-  int debug;
+  int verbose;
   file_data_t *(*get_dir)(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int first_inode);
   int (*copy_file)(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const file_data_t *file);
   void (*close)(dir_data_t *dir_data);
@@ -50,12 +49,6 @@ struct file_data
   struct stat filestat;
 };
 
-struct file_info {
-  struct list_head list;
-  char name[4096];
-  struct stat stat;
-};
-
 int dir_aff_log(const disk_t *disk_car, const partition_t *partition, const dir_data_t *dir_data, const file_data_t*dir_list);
 void delete_list_file(file_data_t *file_list);
 int dir_partition_aff(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int inode, char **current_cmd);
