@@ -9,7 +9,7 @@ typedef enum photorec_status photorec_status_t;
 typedef struct list_cluster_struct list_cluster_t;
 struct list_cluster_struct
 {
-  struct list_head list;
+  struct td_list_head list;
   uint64_t offset;
   uint32_t cluster;
   file_data_t *dir_list;
@@ -27,7 +27,6 @@ partition_t *new_whole_disk(const disk_t *disk_car);
 unsigned int find_blocksize(alloc_data_t *list_file, const unsigned int default_blocksize, uint64_t *offset);
 alloc_data_t * update_blocksize(unsigned int blocksize, alloc_data_t *list_search_space, const uint64_t offset);
 void list_cluster_free(list_cluster_t *list_cluster);
-unsigned int find_blocksize_cluster(list_cluster_t *list_cluster, const unsigned int default_blocksize, uint64_t *offset);
 void forget(alloc_data_t *list_search_space, alloc_data_t *current_search_space);
 alloc_data_t *init_search_space(const partition_t *partition, const disk_t *disk_car);
 unsigned int remove_used_space(disk_t *disk_car, const partition_t *partition, alloc_data_t *list_search_space);
@@ -35,4 +34,5 @@ void free_list_search_space(alloc_data_t *list_search_space);
 int sorfile_stat_ts(const void *p1, const void *p2);
 unsigned int photorec_mkdir(const char *recup_dir, const unsigned int initial_dir_num);
 void list_space_used(const file_recovery_t *file_recovery, const unsigned int sector_size);
+void info_list_search_space(const alloc_data_t *list_search_space, const alloc_data_t *current_search_space, const unsigned int sector_size, const int keep_corrupted_file, const int verbose);
 
